@@ -13,7 +13,7 @@ use Tags::HTML::Messages;
 
 Readonly::Array our @FORM_METHODS => qw(post get);
 
-our $VERSION = 0.05;
+our $VERSION = 0.06;
 
 # Constructor.
 sub new {
@@ -352,7 +352,7 @@ Returns undef.
                  Parameter 'css' isn't defined.
          Message types must be a hash reference.
 
-=head1 EXAMPLE
+=head1 EXAMPLE1
 
 =for comment filename=print_block_html_and_css.pl
 
@@ -462,6 +462,53 @@ Returns undef.
  #   </fieldset>
  # </form>
 
+=head1 EXAMPLE2
+
+=for comment filename=plack_app_login_register.pl
+
+ use strict;
+ use warnings;
+ 
+ use CSS::Struct::Output::Indent;
+ use Plack::App::Tags::HTML;
+ use Plack::Runner;
+ use Tags::HTML::Login::Register;
+ use Tags::Output::Indent;
+ use Unicode::UTF8 qw(decode_utf8);
+ 
+ my $css = CSS::Struct::Output::Indent->new;
+ my $tags = Tags::Output::Indent->new(
+         'xml' => 1,
+         'preserved' => ['style'],
+ );
+ my $register = Tags::HTML::Login::Register->new(
+         'css' => $css,
+         'tags' => $tags,
+ );
+ $register->process_css;
+ my $app = Plack::App::Tags::HTML->new(
+         'component' => 'Tags::HTML::Container',
+         'data' => [sub {
+                 my $self = shift;
+                 $register->process;
+                 return;
+         }],
+         'css' => $css,
+         'tags' => $tags,
+         'title' => 'Register',
+ )->to_app;
+ Plack::Runner->new->run($app);
+
+ # Output screenshot is in images/ directory.
+
+=begin html
+
+<a href="https://raw.githubusercontent.com/michal-josef-spacek/Tags-HTML-Login-Register/master/images/plack_app_login_register.png">
+  <img src="https://raw.githubusercontent.com/michal-josef-spacek/Tags-HTML-Login-Register/master/images/plack_app_login_register.png" alt="Web app example" width="300px" height="300px" />
+</a>
+
+=end html
+
 =head1 DEPENDENCIES
 
 L<Class::Utils>,
@@ -503,6 +550,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.05
+0.06
 
 =cut
